==> blesta-5.10.2.zip: blesta/plugins/system_status/language/tr_tr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.index.sql_mariadb_version_requirements'] = 'Minimum gerekliliklere bakın';
$lang['AdminMain.index.sql_mariadb_version_serious'] = 'MariaDB sürümü minimum sistem gereksinimlerini karşılamıyor.';
$lang['AdminMain.index.sql_mysql_version_requirements'] = 'Minimum gerekliliklere bakın';
$lang['AdminMain.index.sql_mysql_version_serious'] = 'MySQL sürümü minimum sistem gereksinimlerini karşılamıyor.';
$lang['AdminMain.index.php_version_requirements'] = 'Minimum gerekliliklere bakın';
$lang['AdminMain.index.php_version_serious'] = 'PHP sürümü minimum sistem gereksinimlerini karşılamıyor.';
$lang['AdminMain.index.db_version_upgrade'] = 'Yükseltme mi?';
$lang['AdminMain.index.db_version_serious'] = 'Veritabanı sürümü sistem sürümüyle eşleşmiyor.';
$lang['AdminMain.index.updates_buy'] = 'Destek ve güncelleme ekleyelim mi?';
$lang['AdminMain.index.updates_serious'] = 'Destek ve güncellemelerinizin süresi %1$s tarihinde doldu.';
$lang['AdminMain.index.updates_minor'] = 'Desteğiniz ve güncellemeleriniz %1$s\'a kadar iyi.';
$lang['AdminMain.index.updates_forever'] = 'Desteğiniz ve güncellemeleriniz sonsuza dek sürecek.';
$lang['AdminMain.index.error_reporting'] = 'errorReporting veya System.debug /config/blesta.php dosyasında etkinleştirilir. Bir sorunu aktif olarak gidermediğiniz sürece, bunlar devre dışı bırakılmalıdır. errorReporting 0, System.debug false olmalıdır.';
$lang['AdminMain.index.log_files_owner_minor'] = 'Web sunucusuyla aynı kullanıcıya ait olmayan bazı günlük dosyaları var.  Bu genellikle cron\'un web sunucusundan farklı bir kullanıcı olarak çalışmasından kaynaklanır.';
$lang['AdminMain.index.system_dir_writable_setting'] = 'Güncelleme mi?';
$lang['AdminMain.index.system_dir_writable_minor'] = 'Bir sistem dizini yazılabilir değildir.';
$lang['AdminMain.index.docroot_setting'] = 'Güncelleme mi?';
$lang['AdminMain.index.docroot_minor'] = 'Algılanan belge kök yolu Kök Web Dizini ayarıyla eşleşmiyor.';
$lang['AdminMain.index.backup_minor'] = 'Son 7 gün içinde hiç yedekleme yapılmadı.';
$lang['AdminMain.index.invoices_configure'] = 'Yapılandırmak mı?';
$lang['AdminMain.index.invoices_minor'] = 'Faturalar son 24 saat içinde cron aracılığıyla otomatik olarak oluşturulmadı.';
$lang['AdminMain.index.trial_buy'] = 'Şimdi mi alayım?';
$lang['AdminMain.index.trial_minor'] = 'Deneme lisansınızın süresi %1$s tarihinde sona eriyor.';
$lang['AdminMain.index.cron_task_stalled_automation'] = 'Otomatik Görevleri Görüntüle';
$lang['AdminMain.index.cron_task_stalled_minor'] = '1$s dakikadan daha uzun süredir yürütülmekte olan bir veya daha fazla cron görevi var.';
$lang['AdminMain.index.cron_configure'] = 'Yapılandırmak mı?';
$lang['AdminMain.index.cron_minor'] = 'Cron son 24 saat içinde çalışmadı.';
$lang['AdminMain.index.cron_serious'] = 'Cron hiç çalışmadı.';
$lang['AdminMain.index.boxtitle_feed'] = 'Sistem Durumu';
$lang['AdminMain.index.health_poor'] = 'Sistemin normal çalışmasını etkileyen ciddi sorunlar vardır. Bunlar mümkün olan en kısa sürede çözülmelidir.';
$lang['AdminMain.index.health_fair'] = 'Sistemin normal çalışmasını etkileyen bazı sorunlar vardır.';
$lang['AdminMain.index.health_good'] = 'Genel olarak sistem iyi durumda, ancak dikkatinizi gerektirebilecek bazı öğeler var.';
$lang['AdminMain.index.health_excellent'] = 'Sistemin sağlığı iyi durumdadır ve normal çalışıyor gibi görünmektedir.';

==> blesta-5.11.4.zip: blesta/plugins/system_status/language/tr_tr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.index.sql_mariadb_version_requirements'] = 'Minimum gerekliliklere bakın';
$lang['AdminMain.index.sql_mariadb_version_serious'] = 'MariaDB sürümü minimum sistem gereksinimlerini karşılamıyor.';
$lang['AdminMain.index.sql_mysql_version_requirements'] = 'Minimum gerekliliklere bakın';
$lang['AdminMain.index.sql_mysql_version_serious'] = 'MySQL sürümü minimum sistem gereksinimlerini karşılamıyor.';
$lang['AdminMain.index.php_version_requirements'] = 'Minimum gerekliliklere bakın';
$lang['AdminMain.index.php_version_serious'] = 'PHP sürümü minimum sistem gereksinimlerini karşılamıyor.';
$lang['AdminMain.index.db_version_upgrade'] = 'Yükseltme mi?';
$lang['AdminMain.index.db_version_serious'] = 'Veritabanı sürümü sistem sürümüyle eşleşmiyor.';
$lang['AdminMain.index.updates_buy'] = 'Destek ve güncelleme ekleyelim mi?';
$lang['AdminMain.index.updates_serious'] = 'Destek ve güncellemelerinizin süresi %1$s tarihinde doldu.';
$lang['AdminMain.index.updates_minor'] = 'Desteğiniz ve güncellemeleriniz %1$s\'a kadar iyi.';
$lang['AdminMain.index.updates_forever'] = 'Desteğiniz ve güncellemeleriniz sonsuza dek sürecek.';
$lang['AdminMain.index.error_reporting'] = 'errorReporting veya System.debug /config/blesta.php dosyasında etkinleştirilir. Bir sorunu aktif olarak gidermediğiniz sürece, bunlar devre dışı bırakılmalıdır. errorReporting 0, System.debug false olmalıdır.';
$lang['AdminMain.index.log_files_owner_minor'] = 'Web sunucusuyla aynı kullanıcıya ait olmayan bazı günlük dosyaları var.  Bu genellikle cron\'un web sunucusundan farklı bir kullanıcı olarak çalışmasından kaynaklanır.';
$lang['AdminMain.index.system_dir_writable_setting'] = 'Güncelleme mi?';
$lang['AdminMain.index.system_dir_writable_minor'] = 'Bir sistem dizini yazılabilir değildir.';
$lang['AdminMain.index.docroot_setting'] = 'Güncelleme mi?';
$lang['AdminMain.index.docroot_minor'] = 'Algılanan belge kök yolu Kök Web Dizini ayarıyla eşleşmiyor.';
$lang['AdminMain.index.backup_minor'] = 'Son 7 gün içinde hiç yedekleme yapılmadı.';
$lang['AdminMain.index.invoices_configure'] = 'Yapılandırmak mı?';
$lang['AdminMain.index.invoices_minor'] = 'Faturalar son 24 saat içinde cron aracılığıyla otomatik olarak oluşturulmadı.';
$lang['AdminMain.index.trial_buy'] = 'Şimdi mi alayım?';
$lang['AdminMain.index.trial_minor'] = 'Deneme lisansınızın süresi %1$s tarihinde sona eriyor.';
$lang['AdminMain.index.cron_task_stalled_automation'] = 'Otomatik Görevleri Görüntüle';
$lang['AdminMain.index.cron_configure'] = 'Yapılandırmak mı?';
$lang['AdminMain.index.cron_minor'] = 'Cron son 24 saat içinde çalışmadı.';
$lang['AdminMain.index.cron_serious'] = 'Cron hiç çalışmadı.';
$lang['AdminMain.index.boxtitle_feed'] = 'Sistem Durumu';
$lang['AdminMain.index.health_poor'] = 'Sistemin normal çalışmasını etkileyen ciddi sorunlar vardır. Bunlar mümkün olan en kısa sürede çözülmelidir.';
$lang['AdminMain.index.health_fair'] = 'Sistemin normal çalışmasını etkileyen bazı sorunlar vardır.';
$lang['AdminMain.index.health_good'] = 'Genel olarak sistem iyi durumda, ancak dikkatinizi gerektirebilecek bazı öğeler var.';
$lang['AdminMain.index.health_excellent'] = 'Sistemin sağlığı iyi durumdadır ve normal çalışıyor gibi görünmektedir.';
$lang['AdminMain.index.cron_task_stalled_minor'] = 'Bir veya daha fazla cron görevi %1$s dakikadan uzun süredir yürütülüyor.';
$lang['AdminMain.index.upload_dir_configure'] = 'Yapılandırmak mı?';
$lang['AdminMain.index.upload_dir'] = 'Ayarlarınızdaki yükleme dizini yolu kök web dizini içindedir.  Herkesin erişimine açık olmasıyla ilgili bir sorun yaşanmamasını sağlamak için kök web dizininin üzerine yerleştirilmelidir.';
